# from utils import saybye
import argparse
import logging
import os.path
from typing import Dict, List, cast



# def main(args: List[str]) -> None:
#     parser = argparse.ArgumentParser(prog="twine upload")
#     # settings.Settings.register_argparse_arguments(parser)
#     parser.add_argument(
#         "dists",
#         nargs="+",
#         metavar="dist",
#         help="The distribution files to upload to the repository "
#              "(package index). Usually dist/* . May additionally contain "
#              "a .asc file to include an existing signature with the "
#              "file upload.",
#     )
#
#     parsed_args = parser.parse_args(args)
#
#     print("upload main ")
#     # upload_settings = settings.Settings.from_argparse(parsed_args)
#
#     # Call the upload function with the arguments from the command line
#     # return upload(upload_settings, parsed_args.dists)


def main():
    print('he111llo')
    # saybye()

def main2():
    print('hello222')
    # saybye()


#
# if __name__=='__main__':
#     main()


# Copyright 2013 Donald Stufft
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import argparse
import logging
import os.path
from typing import Dict, List, cast

import requests


logger = logging.getLogger(__name__)


def main(args: List[str]) -> None:
    parser = argparse.ArgumentParser(prog="twine upload")
    # settings.Settings.register_argparse_arguments(parser)
    parser.add_argument(
        "dists",
        nargs="+",
        metavar="dist",
        help="The distribution files to upload to the repository "
        "(package index). Usually dist/* . May additionally contain "
        "a .asc file to include an existing signature with the "
        "file upload.",
    )

    parsed_args = parser.parse_args(args)

    print("upload main ")
    # upload_settings = settings.Settings.from_argparse(parsed_args)

    # Call the upload function with the arguments from the command line
    # return upload(upload_settings, parsed_args.dists)



import base64
import os
def Base_64(PATH,IMGNAME):
    file_path = os.path.join(PATH,IMGNAME) #获取base_dir+'/image'文件夹内的文件
    f=open(file_path,'rb') #二进制方式打开图文件
    lsReadImage_f=base64.b64encode(f.read())#读取文件内容，转换为base64编码
    f.close()#关闭文件
    return "0.0.7"+str(lsReadImage_f)


#!/usr/bin/env python
from setuptools import setup, find_packages
setup( name = 'lyptest1',
       version = '0.0.26', description = 'python 3.7-->3.6 ', long_description = 'library ',
       author = 'pylyp456', author_email = '25506871@qq.com', url = 'https://github.com/ligaopan/lgp-library', license = 'MIT Licence', keywords = 'testing testautomation', platforms = 'any',

       python_requires = '>=3.6.*', install_requires = [],
       package_dir = {'': 'src'}, packages = find_packages('src')
,
       entry_points = {
              'console_scripts': [
                     # 'say4 = twine2.hello:main',
                     'say4 = twine2.__main__:main',
              ],
              'lyptest1.registered_commands': [
                     'upload = twine2.commands.upload:main',
              ],
       }


       )